@@ -1,11 +1,13 @@
 """Helper functions for writing rST files."""
 from collections import namedtuple
+from typing import List, Optional, Union
 import pathlib
 
 import pytest_bdd.feature
 
 from .base import BaseModel
 
+BlankString = str
 InlineTable = namedtuple("InlineTable", ["headings", "rows"])
 
 
@@ -13,7 +15,7 @@ class PytestModel(BaseModel):
     """Base Model for Pytest-Bdd objects."""
 
     @property
-    def description(self):
+    def description(self) -> Optional[List[str]]:
         """Return description as a list of lines."""
         description = getattr(self._data, "description", None)
         if description:
@@ -23,7 +25,7 @@ class PytestModel(BaseModel):
         return description
 
     @property
-    def keyword(self):
+    def keyword(self) -> str:
         """Return the keyword for a given item."""
         keyword = getattr(
             self._data, "keyword", self._data.__class__.__name__.rsplit(".", 1)[-1]
@@ -33,7 +35,7 @@ class PytestModel(BaseModel):
         return keyword
 
     @property
-    def name(self):
+    def name(self) -> str:
         """Return the name for a given item, if available."""
         return getattr(self._data, "name", None) or ""
 
@@ -42,23 +44,23 @@ class Step(PytestModel):
     """Step model for Pytest-Bdd."""
 
     @property
-    def filename(self):
+    def filename(self) -> str:
         """Return the source file path for the step."""
         parent = self._data.scenario or self._data.background
         return parent.feature.filename
 
     @property
-    def line(self):
+    def line(self) -> int:
         """Return the line number from the source file."""
         return self._data.line_number
 
     @property
-    def step_type(self):
+    def step_type(self) -> str:
         """Return the step type/keyword."""
         return self.keyword
 
     @property
-    def table(self):
+    def table(self) -> Union[InlineTable, BlankString]:
         """Return the step table, if present."""
         lines = self._data.lines
         if lines and all("|" in x for x in lines):
@@ -70,7 +72,7 @@ class Step(PytestModel):
         return ""
 
     @property
-    def text(self):
+    def text(self) -> Union[List[str], BlankString]:
         """Return the (non-table) multi-line text from a step."""
         if self.table:
             # pytest-bdd doesn't distinguish between table and text
@@ -83,7 +85,7 @@ class Step(PytestModel):
         ]
 
     @property
-    def name(self):
+    def name(self) -> str:
         """Return text after keyword."""
         return self._data.name.splitlines()[0]
 
@@ -92,7 +94,7 @@ class Background(PytestModel):
     """Background model for Pytest-Bdd."""
 
     @property
-    def steps(self):
+    def steps(self) -> List[Step]:
         """Return the steps from the background."""
         return [Step(s) for s in self._data.steps]
 
@@ -101,12 +103,12 @@ class Example(PytestModel):
     """Example model for Pytest-Bdd."""
 
     @property
-    def tags(self):
+    def tags(self) -> list:
         """Return an empty list of tags, as Pytest-Bdd does not support example tags."""
         return []
 
     @property
-    def table(self):
+    def table(self) -> InlineTable:
         """Return the Example table."""
         return InlineTable(headings=self._data.example_params, rows=self._data.examples)
 
@@ -115,12 +117,12 @@ class Scenario(PytestModel):
     """Scenario model for Pytest-Bdd."""
 
     @property
-    def steps(self):
+    def steps(self) -> List[Step]:
         """Return (non-background) steps for the scenario."""
         return [Step(s) for s in self._data.steps if not s.background]
 
     @property
-    def examples(self):
+    def examples(self) -> List[Optional[Example]]:
         """Return examples from the scenario, if any exist."""
         if self._data.examples.examples:
             return [Example(self._data.examples)]
@@ -130,24 +132,24 @@ class Scenario(PytestModel):
 class Feature(PytestModel):
     """Feature model for Pytest-Bdd."""
 
-    def __init__(self, root_path, source_path):
+    def __init__(self, root_path: str, source_path: str):
         self._data = pytest_bdd.feature.Feature(
             root_path, pathlib.Path(source_path).resolve().relative_to(root_path)
         )
 
     @property
-    def scenarios(self):
+    def scenarios(self) -> List[Scenario]:
         """Return all scenarios for the feature."""
         return [Scenario(s) for s in self._data.scenarios.values()]
 
     @property
-    def background(self):
+    def background(self) -> Optional[Background]:
         """Return the background for the feature."""
         background_entry = self._data.background
         return Background(background_entry) if background_entry else None
 
     @property
-    def examples(self):
+    def examples(self) -> List[Optional[Example]]:
         """Return feature-level examples, if any exist."""
         if self._data.examples.examples:
             return [Example(self._data.examples)]
